<?php
require_once( get_stylesheet_directory() . '/lib/ally-license.php' );
// Load the API Key library if it is not already loaded. Must be placed in the root plugin file.
if (  class_exists( 'Ally_License_Theme' ) ) {
    /**
     * @param string $file             Must be __FILE__ from the root plugin file, or theme functions file.
     * @param string $software_title   Must be exactly the same as the Software Title in the product.
     * @param string $software_version This product's current software version.
     * @param string $plugin_or_theme  'plugin' or 'theme'
     * @param string $api_url          The URL to the site that is running the API Manager. Example: https://www.toddlahman.com/
     *
     * @return \AM_License_Submenu|null
     */
    Ally_License_Theme::instance( __FILE__, 'Ally', '1.3.1', 'theme', 'https://divilover.com/' );
}

function dl_styles_enqueue()
	{
	wp_enqueue_style('parent-style', get_template_directory_uri() . '/style.css', 1);
	}

add_action('wp_enqueue_scripts', 'dl_styles_enqueue');

function dl_scripts_enqueue()
	{
	wp_enqueue_script('flexslider-scripts', get_stylesheet_directory_uri() . '/scripts/ally-plugins.js', array( 'jquery' ) , 1, 1);
	wp_enqueue_script('custom-scripts', get_stylesheet_directory_uri() . '/scripts/ally-custom-scripts.js', array( 'jquery' ) , 1, 1);
	}

add_action('wp_enqueue_scripts', 'dl_scripts_enqueue', 13, 1);

// include Theme Customizer editors;

include ('editor/customizer.php');
include ('editor/login-editor.php');

// One Click Instalation - tgm plugin activation

require_once get_stylesheet_directory() . '/installer/class-tgm-plugin-activation.php';
add_action('tgmpa_register', 'ally_tgm_register_required_plugins');

// Register the required plugins for this theme.

function ally_tgm_register_required_plugins()
	{
	$plugins = array(

		// Include a plugin from the WordPress Plugin Repository.
		array(
			'name' => 'One Click Demo Import',
			'slug' => 'one-click-demo-import',
			'required' => true,
		) ,

		// Include a plugin bundled with a theme.
		array(
			'name' => 'Divi Widget Builder', // The plugin name.
			'slug' => 'divi-widget-builder', // The plugin slug (typically the folder name).
			'source' => get_stylesheet_directory() . '/plugins/Divi_Widget_Builder.zip', // The plugin source.
			'required' => true, // If false, the plugin is only 'recommended' instead of required.
			'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url' => '', // If set, overrides default API URL and points to an external URL.
			'is_callable' => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
		) ,
	);
	$config = array(
		'id' => 'ally', // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '', // Default absolute path to bundled plugins.
		'menu' => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug' => 'themes.php', // Parent menu slug.
		'capability' => 'edit_theme_options', // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices' => true, // Show admin notices or not.
		'dismissable' => true, // If false, a user cannot dismiss the nag message.
		'dismiss_msg' => '', // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true, // Automatically activate plugins after installation or not.
		'message' => '', // Message to output right before the plugins table.
	);
	tgmpa($plugins, $config);
	}

add_filter('pt-ocdi/disable_pt_branding', '__return_true');
// Import Demo Content 

function ocdi_import_files()
	{
	return array(
		array(
			'import_file_name' => 'Demo Import',
			'import_file_url' => 'https://divilover.com/demo_import/ally/ally-demo-content.xml',
			'import_widget_file_url' => 'https://divilover.com/demo_import/ally/ally-widgets.wie',
			'import_customizer_file_url' => 'https://divilover.com/demo_import/ally/theme-customizer.dat',
			'import_preview_image_url' => 'https://divilover.com/demo_import/ally/ally_preview.jpg',
			'import_notice' => __('Your new website is almost ready - Click Import & have fun!', 'your-textdomain') ,
		) ,
	);
	}

add_filter('pt-ocdi/import_files', 'ocdi_import_files');

// Clear Default Widgets

function ocdi_before_widgets_import($selected_import)
	{
	if (!get_option('acme_cleared_widgets'))
		{
		update_option('sidebars_widgets', array());
		update_option('acme_cleared_widgets', true);
		}
	}

add_action('pt-ocdi/before_widgets_import', 'ocdi_before_widgets_import');

// After import... 

function ocdi_after_import_setup()
	{

	// Asign Menus
	$main_menu = get_term_by('name', 'Main Menu', 'nav_menu');
	set_theme_mod('nav_menu_locations', array(
		'primary-menu' => $main_menu->term_id,
	));
	
	// Set Front Page from Reading Options
	$front_page_id = get_page_by_title('Homepage');

	// Set Blog Page from Reading Options
	$blog_page_id = get_page_by_title('Blog with sidebar');
	
	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );
	
	}

add_action('pt-ocdi/after_import', 'ocdi_after_import_setup');

// Add new Widget Area - Popup 

function ally_register_popup_widget()
	{
	register_sidebar(array(
		'name' => 'Ally - Popup Widget',
		'id' => 'ally-popup',
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));
	}

add_action('widgets_init', 'ally_register_popup_widget');

function ally_display_popup_widget()
	{ ?>
    <div id="open-popup" class="ally-white-popup mfp-hide mfp-fade">
        <?php
	dynamic_sidebar('ally-popup'); ?>
    </div>
<?php
	}

add_action('wp_footer', 'ally_display_popup_widget');

// Add new Widget Area - Before Footer 

function ally_register_footer_widget()
	{
	register_sidebar(array(
		'name' => 'Ally Footer',
		'id' => 'ally-footer',
		'before_widget' => '<div id="%1$s" class="%2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
	));
	}

add_action('widgets_init', 'ally_register_footer_widget');

function ally_display_footer_widget()
	{ ?>
    <div id="ally-footer">
        <?php
	dynamic_sidebar('ally-footer'); ?>
    </div>
<?php
	}

add_action('wp_footer', 'ally_display_footer_widget');

// Add images to Recent Post Widget

Class Ally_Widget_Recent_Posts extends WP_Widget_Recent_Posts
	{
	function widget($args, $instance)
		{
		if (!isset($args['widget_id']))
			{
			$args['widget_id'] = $this->id;
			}

		$title = (!empty($instance['title'])) ? $instance['title'] : __('Recent Posts');
		$title = apply_filters('widget_title', $title, $instance, $this->id_base);
		$number = (!empty($instance['number'])) ? absint($instance['number']) : 5;
		if (!$number) $number = 5;
		$show_date = isset($instance['show_date']) ? $instance['show_date'] : false;
		$r = new WP_Query(apply_filters('widget_posts_args', array(
			'posts_per_page' => $number,
			'no_found_rows' => true,
			'post_status' => 'publish',
			'ignore_sticky_posts' => true
		)));
		if ($r->have_posts()):
?>
            <?php
			echo $args['before_widget']; ?>
            <?php
			if ($title)
				{
				echo $args['before_title'] . $title . $args['after_title'];
				} ?>
            <ul>
            <?php
			while ($r->have_posts()):
				$r->the_post(); ?>
                <li>
                <a href="<?php
				the_permalink(); ?>" class="clearfix">
                    <?php
				the_post_thumbnail('thumbnail'); ?>
                    <span><?php
				get_the_title() ? the_title() : the_ID(); ?>
	                <?php
				if ($show_date): ?>
	                    <br/><small class="post-date"><?php
					echo get_the_date(); ?></small>
	                <?php
				endif; ?>
	                </span>
                </a>
                </li>
            <?php
			endwhile; ?>
            </ul>
            <?php
			echo $args['after_widget']; ?>
            <?php

			// Reset the global $the_post as this query will have stomped on it

			wp_reset_postdata();
		endif;
		}
	}

function ally_widget_registration()
	{
	unregister_widget('WP_Widget_Recent_Posts');
	register_widget('Ally_Widget_Recent_Posts');
	}

add_action('widgets_init', 'ally_widget_registration');
?>